<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="73"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <location filename="bookmarks_dialog.cpp" line="75"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="107"/>
        <location filename="bookmarks_dialog.cpp" line="124"/>
        <source>Loading...</source>
        <translation>Yükleniyor...</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="85"/>
        <source>Click on any image to go to the bookmark</source>
        <translation>Yer imine git</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="25"/>
        <source>Lastest Page</source>
        <translation>Son Sayfa</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="23"/>
        <source>Restore defaults</source>
        <translation>Varsayılarları geri yükle</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="24"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation>Bir kısayolu değiştirmek için tuş kombinasyonuna çift tıklayın ve yeni tuşları girin.</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="71"/>
        <source>Shortcuts settings</source>
        <translation>Kısayol oyarları</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation>Kısayol kullanımda</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation>&quot;%1&quot; kısayolu bir başka işleve zaten atanmış</translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation>7z bulunamadı</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation>(%1). sayfada CRC hatası : bazı sayfalar düzgün görüntülenmeyecek</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation>Dosya açılırken bilinmeyen hata</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation>Biçim desteklenmiyor</translation>
    </message>
</context>
<context>
    <name>GoToDialog</name>
    <message>
        <location filename="goto_dialog.cpp" line="23"/>
        <source>Go To</source>
        <translation>Git</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="53"/>
        <source>Go to...</source>
        <translation>Git...</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="39"/>
        <location filename="goto_dialog.cpp" line="71"/>
        <source>Total pages : </source>
        <translation>Toplam sayfa: </translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="15"/>
        <source>Page : </source>
        <translation>Sayfa : </translation>
    </message>
</context>
<context>
    <name>GoToFlowToolBar</name>
    <message>
        <location filename="goto_flow_toolbar.cpp" line="38"/>
        <source>Page : </source>
        <translation>Sayfa : </translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="30"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="33"/>
        <source>System info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="27"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation>Günlük penceresi</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation>&amp;Duraklat</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation>&amp;Kaydet</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation>&amp;Temizle</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation>&amp;Otomatik kaydır</translation>
    </message>
</context>
<context>
    <name>MainWindowViewer</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Yardım</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Kaydet</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="vanished">&amp;Dosya</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="vanished">&amp;İleri</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Aç</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
    <message>
        <source>Open Comic</source>
        <translation type="vanished">Çizgi Romanı Aç</translation>
    </message>
    <message>
        <source>Go To</source>
        <translation type="vanished">Git</translation>
    </message>
    <message>
        <source>Open image folder</source>
        <translation type="vanished">Resim dosyasınıaç</translation>
    </message>
    <message>
        <source>Set bookmark</source>
        <translation type="vanished">Yer imi yap</translation>
    </message>
    <message>
        <source>page_%1.jpg</source>
        <translation type="vanished">sayfa_%1.jpg</translation>
    </message>
    <message>
        <source>Switch to double page mode</source>
        <translation type="vanished">Çift sayfa moduna geç</translation>
    </message>
    <message>
        <source>Save current page</source>
        <translation type="vanished">Geçerli sayfayı kaydet</translation>
    </message>
    <message>
        <source>Double page mode</source>
        <translation type="vanished">Çift sayfa modu</translation>
    </message>
    <message>
        <source>Switch Magnifying glass</source>
        <translation type="vanished">Büyüteç</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="vanished">Dosyayı Aç</translation>
    </message>
    <message>
        <source>Comic files</source>
        <translation type="vanished">Çizgi Roman Dosyaları</translation>
    </message>
    <message>
        <source>Go to previous page</source>
        <translation type="vanished">Önceki sayfaya dön</translation>
    </message>
    <message>
        <source>Open a comic</source>
        <translation type="vanished">Çizgi romanı aç</translation>
    </message>
    <message>
        <source>Image files (*.jpg)</source>
        <translation type="vanished">Resim dosyaları (*.jpg)</translation>
    </message>
    <message>
        <source>Next Comic</source>
        <translation type="vanished">Sırada ki çizgi roman</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation type="vanished">Uygun Genişlik</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="vanished">Ayarlar</translation>
    </message>
    <message>
        <source>Show Info</source>
        <translation type="vanished">Bilgiyi göster</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Dosyayı aç</translation>
    </message>
    <message>
        <source>Go to page ...</source>
        <translation type="vanished">Sayfata git...</translation>
    </message>
    <message>
        <source>Fit image to width</source>
        <translation type="vanished">Görüntüyü sığdır</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="vanished">&amp;Geri</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation type="vanished">Sonra ki sayfaya geç</translation>
    </message>
    <message>
        <source>Show keyboard shortcuts</source>
        <translation type="vanished">Klavye kısayollarını göster</translation>
    </message>
    <message>
        <source>There is a new version available</source>
        <translation type="vanished">Yeni versiyon mevcut</translation>
    </message>
    <message>
        <source>Open next comic</source>
        <translation type="vanished">Sıradaki çizgi romanı aç</translation>
    </message>
    <message>
        <source>Show bookmarks</source>
        <translation type="vanished">Yer imlerini göster</translation>
    </message>
    <message>
        <source>Open previous comic</source>
        <translation type="vanished">Önceki çizgi romanı aç</translation>
    </message>
    <message>
        <source>Rotate image to the left</source>
        <translation type="vanished">Sayfayı sola yatır</translation>
    </message>
    <message>
        <source>Fit image to height</source>
        <translation type="vanished">Uygun yüksekliğe getir</translation>
    </message>
    <message>
        <source>Show the bookmarks of the current comic</source>
        <translation type="vanished">Bu çizgi romanın yer imlerini göster</translation>
    </message>
    <message>
        <source>Show Dictionary</source>
        <translation type="vanished">Sözlüğü göster</translation>
    </message>
    <message>
        <source>YACReader options</source>
        <translation type="vanished">YACReader ayarları</translation>
    </message>
    <message>
        <source>Help, About YACReader</source>
        <translation type="vanished">YACReader hakkında yardım ve bilgi</translation>
    </message>
    <message>
        <source>Show go to flow</source>
        <translation type="vanished">Akışı göster</translation>
    </message>
    <message>
        <source>Previous Comic</source>
        <translation type="vanished">Önce ki çizgi roman</translation>
    </message>
    <message>
        <source>Show full size</source>
        <translation type="vanished">Tam erken</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation type="vanished">Büyüteç</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Genel</translation>
    </message>
    <message>
        <source>Set a bookmark on the current page</source>
        <translation type="vanished">Sayfayı yer imi olarak ayarla</translation>
    </message>
    <message>
        <source>Do you want to download the new version?</source>
        <translation type="vanished">Yeni versiyonu indirmek ister misin ?</translation>
    </message>
    <message>
        <source>Rotate image to the right</source>
        <translation type="vanished">Sayfayı sağa yator</translation>
    </message>
    <message>
        <source>Always on top</source>
        <translation type="vanished">Her zaman üstte</translation>
    </message>
    <message>
        <source>New instance</source>
        <translation type="vanished">Yeni örnek</translation>
    </message>
    <message>
        <source>Open latest comic</source>
        <translation type="vanished">En son çizgi romanı aç</translation>
    </message>
    <message>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="vanished">Önceki okuma oturumunda açılan en son çizgi romanı aç</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="vanished">Temizle</translation>
    </message>
    <message>
        <source>Clear open recent list</source>
        <translation type="vanished">Son açılanlar listesini temizle</translation>
    </message>
    <message>
        <source>Fit Height</source>
        <translation type="vanished">Yüksekliğe Sığdır</translation>
    </message>
    <message>
        <source>Fit to page</source>
        <translation type="vanished">Sayfaya sığdır</translation>
    </message>
    <message>
        <source>Reset zoom</source>
        <translation type="vanished">Yakınlaştırmayı sıfırla</translation>
    </message>
    <message>
        <source>Show zoom slider</source>
        <translation type="vanished">Yakınlaştırma çubuğunu göster</translation>
    </message>
    <message>
        <source>Zoom+</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom-</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <source>Double page manga mode</source>
        <translation type="vanished">Çift sayfa manga kipi</translation>
    </message>
    <message>
        <source>Reverse reading order in double page mode</source>
        <translation type="vanished">Çift sayfa kipinde ters okuma sırası</translation>
    </message>
    <message>
        <source>Edit shortcuts</source>
        <translation type="vanished">Kısayolları düzenle</translation>
    </message>
    <message>
        <source>Open recent</source>
        <translation type="vanished">Son dosyaları aç</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Dosya</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">Düzen</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Görünüm</translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="vanished">Git</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="vanished">Pencere</translation>
    </message>
    <message>
        <source>Comics</source>
        <translation type="vanished">Çizgi Roman</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode</source>
        <translation type="vanished">Tam ekran kipini aç/kapat</translation>
    </message>
    <message>
        <source>Hide/show toolbar</source>
        <translation type="vanished">Araç çubuğunu göster/gizle</translation>
    </message>
    <message>
        <source>Size up magnifying glass</source>
        <translation type="vanished">Büyüteci büyüt</translation>
    </message>
    <message>
        <source>Size down magnifying glass</source>
        <translation type="vanished">Büyüteci küçült</translation>
    </message>
    <message>
        <source>Zoom in magnifying glass</source>
        <translation type="vanished">Büyüteci yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom out magnifying glass</source>
        <translation type="vanished">Büyüteci uzaklaştır</translation>
    </message>
    <message>
        <source>Magnifiying glass</source>
        <translation type="vanished">Büyüteç</translation>
    </message>
    <message>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="vanished">Genişliğe sığdır ile yüksekliğe sığdır arasında geçiş yap</translation>
    </message>
    <message>
        <source>Page adjustement</source>
        <translation type="vanished">Sayfa ayarı</translation>
    </message>
    <message>
        <source>Autoscroll down</source>
        <translation type="vanished">Otomatik aşağı kaydır</translation>
    </message>
    <message>
        <source>Autoscroll up</source>
        <translation type="vanished">Otomatik yukarı kaydır</translation>
    </message>
    <message>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="vanished">Otomatik ileri kaydır, önce yatay</translation>
    </message>
    <message>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="vanished">Otomatik geri kaydır, önce yatay</translation>
    </message>
    <message>
        <source>Autoscroll forward, vertical first</source>
        <translation type="vanished">Otomatik ileri kaydır, önce dikey</translation>
    </message>
    <message>
        <source>Autoscroll backward, vertical first</source>
        <translation type="vanished">Otomatik geri kaydır, önce dikey</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation type="vanished">Aşağı git</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation type="vanished">Yukarı git</translation>
    </message>
    <message>
        <source>Move left</source>
        <translation type="vanished">Sola git</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation type="vanished">Sağa git</translation>
    </message>
    <message>
        <source>Go to the first page</source>
        <translation type="vanished">İlk sayfaya git</translation>
    </message>
    <message>
        <source>Go to the last page</source>
        <translation type="vanished">En son sayfaya git</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Okuma</translation>
    </message>
    <message>
        <source>Remind me in 14 days</source>
        <translation type="vanished">14 gün içinde hatırlat</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="vanished">Şimdi değil</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="145"/>
        <source>Gamma</source>
        <translation>Gama</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="149"/>
        <source>Reset</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="34"/>
        <source>My comics path</source>
        <translation>Çizgi Romanlarım</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="193"/>
        <source>Image adjustment</source>
        <translation>Resim ayarları</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="43"/>
        <source>&quot;Go to flow&quot; size</source>
        <translation>Akış görünümüne git</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="64"/>
        <source>Choose</source>
        <translation>Seç</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="154"/>
        <source>Image options</source>
        <translation>Sayfa ayarları</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="144"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="208"/>
        <source>Options</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="215"/>
        <source>Comics directory</source>
        <translation>Çizgi roman konumu</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="61"/>
        <source>Background color</source>
        <translation>Arka plan rengi</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="192"/>
        <source>Page Flow</source>
        <translation>Sayfa akışı</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="191"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="143"/>
        <source>Brightness</source>
        <translation>Parlaklık</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="199"/>
        <source>Restart is needed</source>
        <translation>Yeniden başlatılmalı</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="99"/>
        <source>Quick Navigation Mode</source>
        <translation>Hızlı Gezinti Kipi</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="71"/>
        <source>Scroll behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="74"/>
        <source>Disable scroll animations and smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="75"/>
        <source>Do not turn page using scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="76"/>
        <source>Use single scroll step to turn page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="100"/>
        <source>Disable mouse over activation</source>
        <translation>Etkinleştirme üzerinde fareyi devre dışı bırak</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="158"/>
        <source>Fit options</source>
        <translation>Sığdırma seçenekleri</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="160"/>
        <source>Enlarge images to fit width/height</source>
        <translation>Genişliğe/yüksekliği sığmaları için resimleri genişlet</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="171"/>
        <source>Double Page options</source>
        <translation>Çift Sayfa seçenekleri</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="173"/>
        <source>Show covers as single page</source>
        <translation>Kapakları tek sayfa olarak göster</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>7z lib not found</source>
        <translation>7z lib bulunamadı</translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation>./utils içinden 7z lib yüklenemedi</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation>İz</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation>Hata ayıkla</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation>Ölümcül</translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation>Süre</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation>Düzey</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation>Mesaj</translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation>&amp;Duraklat</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation>&amp;Sürdür</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation>Günlük kaydet</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation>Günlük dosyası (*.log)</translation>
    </message>
</context>
<context>
    <name>ShortcutsDialog</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
    <message>
        <source>YACReader keyboard shortcuts</source>
        <translation type="vanished">YACReader klavye kısayolları</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts</source>
        <translation type="vanished">Klavye Kısayolları</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="viewer.cpp" line="51"/>
        <location filename="viewer.cpp" line="924"/>
        <source>Press &apos;O&apos; to open comic.</source>
        <translation>&apos;O&apos;ya basarak aç.</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1128"/>
        <source>Cover!</source>
        <translation>Kapak!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Comic not found</source>
        <translation>Çizgi roman bulunamadı</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Not found</source>
        <translation>Bulunamadı</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1142"/>
        <source>Last page!</source>
        <translation>Son sayfa!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="936"/>
        <source>Loading...please wait!</source>
        <translation>Yükleniyor... lütfen bekleyin!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="240"/>
        <source>Error opening comic</source>
        <translation>Çizgi roman açılırken hata</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>CRC Error</source>
        <translation>CRC Hatası</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="946"/>
        <source>Page not available!</source>
        <translation>Sayfa bulunamadı!</translation>
    </message>
</context>
<context>
    <name>YACReader::MainWindowViewer</name>
    <message>
        <location filename="main_window_viewer.cpp" line="183"/>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="185"/>
        <source>Open a comic</source>
        <translation type="unfinished">Çizgi romanı aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="191"/>
        <source>New instance</source>
        <translation type="unfinished">Yeni örnek</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="210"/>
        <source>Open Folder</source>
        <translation type="unfinished">Dosyayı Aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="212"/>
        <source>Open image folder</source>
        <translation type="unfinished">Resim dosyasınıaç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="217"/>
        <source>Open latest comic</source>
        <translation type="unfinished">En son çizgi romanı aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="218"/>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="unfinished">Önceki okuma oturumunda açılan en son çizgi romanı aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="230"/>
        <source>Clear</source>
        <translation type="unfinished">Temizle</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="231"/>
        <source>Clear open recent list</source>
        <translation type="unfinished">Son açılanlar listesini temizle</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="234"/>
        <source>Save</source>
        <translation type="unfinished">Kaydet</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="236"/>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Save current page</source>
        <translation type="unfinished">Geçerli sayfayı kaydet</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="241"/>
        <source>Previous Comic</source>
        <translation type="unfinished">Önce ki çizgi roman</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="243"/>
        <location filename="main_window_viewer.cpp" line="1641"/>
        <location filename="main_window_viewer.cpp" line="1645"/>
        <source>Open previous comic</source>
        <translation type="unfinished">Önceki çizgi romanı aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="248"/>
        <source>Next Comic</source>
        <translation type="unfinished">Sırada ki çizgi roman</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="250"/>
        <location filename="main_window_viewer.cpp" line="1640"/>
        <location filename="main_window_viewer.cpp" line="1646"/>
        <source>Open next comic</source>
        <translation type="unfinished">Sıradaki çizgi romanı aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="255"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Geri</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="258"/>
        <location filename="main_window_viewer.cpp" line="1643"/>
        <location filename="main_window_viewer.cpp" line="1647"/>
        <source>Go to previous page</source>
        <translation type="unfinished">Önceki sayfaya dön</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="263"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;İleri</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="266"/>
        <location filename="main_window_viewer.cpp" line="1642"/>
        <location filename="main_window_viewer.cpp" line="1648"/>
        <source>Go to next page</source>
        <translation type="unfinished">Sonra ki sayfaya geç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="271"/>
        <source>Fit Height</source>
        <translation type="unfinished">Yüksekliğe Sığdır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="274"/>
        <source>Fit image to height</source>
        <translation type="unfinished">Uygun yüksekliğe getir</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="281"/>
        <source>Fit Width</source>
        <translation type="unfinished">Uygun Genişlik</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="284"/>
        <source>Fit image to width</source>
        <translation type="unfinished">Görüntüyü sığdır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="291"/>
        <source>Show full size</source>
        <translation type="unfinished">Tam erken</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="299"/>
        <source>Fit to page</source>
        <translation type="unfinished">Sayfaya sığdır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="330"/>
        <source>Reset zoom</source>
        <translation type="unfinished">Yakınlaştırmayı sıfırla</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="335"/>
        <source>Show zoom slider</source>
        <translation type="unfinished">Yakınlaştırma çubuğunu göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="338"/>
        <source>Zoom+</source>
        <translation type="unfinished">Yakınlaştır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="343"/>
        <source>Zoom-</source>
        <translation type="unfinished">Uzaklaştır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="348"/>
        <source>Rotate image to the left</source>
        <translation type="unfinished">Sayfayı sola yatır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="354"/>
        <source>Rotate image to the right</source>
        <translation type="unfinished">Sayfayı sağa yator</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="360"/>
        <source>Double page mode</source>
        <translation type="unfinished">Çift sayfa modu</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="361"/>
        <source>Switch to double page mode</source>
        <translation type="unfinished">Çift sayfa moduna geç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="370"/>
        <source>Double page manga mode</source>
        <translation type="unfinished">Çift sayfa manga kipi</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="371"/>
        <source>Reverse reading order in double page mode</source>
        <translation type="unfinished">Çift sayfa kipinde ters okuma sırası</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="380"/>
        <source>Go To</source>
        <translation type="unfinished">Git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="382"/>
        <source>Go to page ...</source>
        <translation type="unfinished">Sayfata git...</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="387"/>
        <source>Options</source>
        <translation type="unfinished">Ayarlar</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="388"/>
        <source>YACReader options</source>
        <translation type="unfinished">YACReader ayarları</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="395"/>
        <location filename="main_window_viewer.cpp" line="689"/>
        <source>Help</source>
        <translation type="unfinished">Yardım</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="396"/>
        <source>Help, About YACReader</source>
        <translation type="unfinished">YACReader hakkında yardım ve bilgi</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="402"/>
        <source>Magnifying glass</source>
        <translation type="unfinished">Büyüteç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="403"/>
        <source>Switch Magnifying glass</source>
        <translation type="unfinished">Büyüteç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="410"/>
        <source>Set bookmark</source>
        <translation type="unfinished">Yer imi yap</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="411"/>
        <source>Set a bookmark on the current page</source>
        <translation type="unfinished">Sayfayı yer imi olarak ayarla</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="420"/>
        <source>Show bookmarks</source>
        <translation type="unfinished">Yer imlerini göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="421"/>
        <source>Show the bookmarks of the current comic</source>
        <translation type="unfinished">Bu çizgi romanın yer imlerini göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="427"/>
        <source>Show keyboard shortcuts</source>
        <translation type="unfinished">Klavye kısayollarını göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="433"/>
        <source>Show Info</source>
        <translation type="unfinished">Bilgiyi göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="439"/>
        <source>Close</source>
        <translation type="unfinished">Kapat</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="445"/>
        <source>Show Dictionary</source>
        <translation type="unfinished">Sözlüğü göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="452"/>
        <source>Show go to flow</source>
        <translation type="unfinished">Akışı göster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="458"/>
        <source>Edit shortcuts</source>
        <translation type="unfinished">Kısayolları düzenle</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="481"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Dosya</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="493"/>
        <location filename="main_window_viewer.cpp" line="644"/>
        <source>Open recent</source>
        <translation type="unfinished">Son dosyaları aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="633"/>
        <source>File</source>
        <translation type="unfinished">Dosya</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="654"/>
        <source>Edit</source>
        <translation type="unfinished">Düzen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="658"/>
        <source>View</source>
        <translation type="unfinished">Görünüm</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="674"/>
        <source>Go</source>
        <translation type="unfinished">Git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="682"/>
        <source>Window</source>
        <translation type="unfinished">Pencere</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Open Comic</source>
        <translation type="unfinished">Çizgi Romanı Aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Comic files</source>
        <translation type="unfinished">Çizgi Roman Dosyaları</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="876"/>
        <source>Open folder</source>
        <translation type="unfinished">Dosyayı aç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>page_%1.jpg</source>
        <translation type="unfinished">sayfa_%1.jpg</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Image files (*.jpg)</source>
        <translation type="unfinished">Resim dosyaları (*.jpg)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1137"/>
        <source>Comics</source>
        <translation type="unfinished">Çizgi Roman</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1147"/>
        <source>Toggle fullscreen mode</source>
        <translation type="unfinished">Tam ekran kipini aç/kapat</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1150"/>
        <source>Hide/show toolbar</source>
        <translation type="unfinished">Araç çubuğunu göster/gizle</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1153"/>
        <source>General</source>
        <translation type="unfinished">Genel</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1172"/>
        <source>Size up magnifying glass</source>
        <translation type="unfinished">Büyüteci büyüt</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1175"/>
        <source>Size down magnifying glass</source>
        <translation type="unfinished">Büyüteci küçült</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1178"/>
        <source>Zoom in magnifying glass</source>
        <translation type="unfinished">Büyüteci yakınlaştır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1181"/>
        <source>Zoom out magnifying glass</source>
        <translation type="unfinished">Büyüteci uzaklaştır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1187"/>
        <source>Magnifiying glass</source>
        <translation type="unfinished">Büyüteç</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1194"/>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="unfinished">Genişliğe sığdır ile yüksekliğe sığdır arasında geçiş yap</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1198"/>
        <source>Page adjustement</source>
        <translation type="unfinished">Sayfa ayarı</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1215"/>
        <source>Autoscroll down</source>
        <translation type="unfinished">Otomatik aşağı kaydır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1218"/>
        <source>Autoscroll up</source>
        <translation type="unfinished">Otomatik yukarı kaydır</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1221"/>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="unfinished">Otomatik ileri kaydır, önce yatay</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1225"/>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="unfinished">Otomatik geri kaydır, önce yatay</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1229"/>
        <source>Autoscroll forward, vertical first</source>
        <translation type="unfinished">Otomatik ileri kaydır, önce dikey</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1233"/>
        <source>Autoscroll backward, vertical first</source>
        <translation type="unfinished">Otomatik geri kaydır, önce dikey</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1237"/>
        <source>Move down</source>
        <translation type="unfinished">Aşağı git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1240"/>
        <source>Move up</source>
        <translation type="unfinished">Yukarı git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1243"/>
        <source>Move left</source>
        <translation type="unfinished">Sola git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1246"/>
        <source>Move right</source>
        <translation type="unfinished">Sağa git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1249"/>
        <source>Go to the first page</source>
        <translation type="unfinished">İlk sayfaya git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1252"/>
        <source>Go to the last page</source>
        <translation type="unfinished">En son sayfaya git</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1255"/>
        <source>Offset double page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1257"/>
        <source>Offset double page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1275"/>
        <source>Reading</source>
        <translation type="unfinished">Okuma</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1320"/>
        <source>There is a new version available</source>
        <translation type="unfinished">Yeni versiyon mevcut</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1321"/>
        <source>Do you want to download the new version?</source>
        <translation type="unfinished">Yeni versiyonu indirmek ister misin ?</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1324"/>
        <source>Remind me in 14 days</source>
        <translation type="unfinished">14 gün içinde hatırlat</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1325"/>
        <source>Not now</source>
        <translation type="unfinished">Şimdi değil</translation>
    </message>
</context>
<context>
    <name>YACReader::WhatsNewDialog</name>
    <message>
        <location filename="../custom_widgets/whats_new_dialog.cpp" line="115"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>Varsayılana ayarla</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="28"/>
        <source>Click to overwrite</source>
        <translation>Üzerine yazmak için tıkla</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>Varsayılana ayarla</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="19"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="44"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="50"/>
        <source>Click to overwrite</source>
        <translation>Üstüne yazmak için tıkla</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>Kapak akışı görünümü</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>Kapaklar nasıl gözüksün:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>Şerit görünüm</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>Çakışan şerit görünüm</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="112"/>
        <source>Zoom</source>
        <translation>Yakınlaş</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="142"/>
        <source>Light</source>
        <translation>Işık</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="76"/>
        <source>Show advanced settings</source>
        <translation>Daha fazla ayar göster</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="32"/>
        <source>Roulette look</source>
        <translation>Rulet görünüm</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="130"/>
        <source>Cover Angle</source>
        <translation>Kapak Açısı</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="23"/>
        <source>Stripe look</source>
        <translation>Strip görünüm</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="94"/>
        <source>Position</source>
        <translation>Pozisyon</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="124"/>
        <source>Z offset</source>
        <translation>Z dengesi</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="118"/>
        <source>Y offset</source>
        <translation>Y dengesi</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="106"/>
        <source>Central gap</source>
        <translation>Boş merkaz</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="18"/>
        <source>Presets:</source>
        <translation>Hazırlayan:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="26"/>
        <source>Overlapped Stripe look</source>
        <translation>Çakışan şerit görünüm</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="29"/>
        <source>Modern look</source>
        <translation>Modern görünüm</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="88"/>
        <source>View angle</source>
        <translation>Bakış açısı</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="148"/>
        <source>Max angle</source>
        <translation>Maksimum açı</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="85"/>
        <source>Custom:</source>
        <translation>Kişisel:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="20"/>
        <source>Classic look</source>
        <translation>Klasik görünüm</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="100"/>
        <source>Cover gap</source>
        <translation>Kapak boşluğu</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="182"/>
        <source>High Performance</source>
        <translation>Yüksek performans</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="201"/>
        <source>Performance:</source>
        <translation>Performans:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="193"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>VSync kullan</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="136"/>
        <source>Visibility</source>
        <translation>Görünülebilirlik</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="180"/>
        <source>Low Performance</source>
        <translation>Düşük Performans</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="46"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>Yüksek donanımlı kullan (yeniden başlatmak gerekli)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="34"/>
        <source>Edit shortcuts</source>
        <translation>Kısayolları düzenle</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="37"/>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
</context>
<context>
    <name>YACReaderSlider</name>
    <message>
        <location filename="width_slider.cpp" line="49"/>
        <source>Reset</source>
        <translation>Yeniden başlat</translation>
    </message>
</context>
<context>
    <name>YACReaderTranslator</name>
    <message>
        <location filename="translator.cpp" line="62"/>
        <source>YACReader translator</source>
        <translation>YACReader çevirmeni</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="116"/>
        <location filename="translator.cpp" line="207"/>
        <source>Translation</source>
        <translation>Çeviri</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="139"/>
        <source>clear</source>
        <translation>temizle</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="216"/>
        <source>Service not available</source>
        <translation>Servis kullanılamıyor</translation>
    </message>
</context>
</TS>
